virtualenv: Virtual Python Environment builder
==============================================

Description
-----------

Virtual Python Environment builder

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/virtualenv/

